/*
 *  Copyright (C) 1999, 2000 Bruno Pires Marinho
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _DIALOGS_H
#define _DIALOGS_H

#include "file-list.h"

void dialog_about (void);

void dialog_new (void);

void dialog_numdown (void);

void dialog_restart (void);

void dialog_remove (void);

void dialog_prefs (void);

void dialog_prop (gboolean open_dialog);

void dialog_add (gchar *uri_list);

void dialog_stats_show (void);

void dialog_stats_update (FileListStats *stats);

#endif /* _DIALOGS_H */
